@@ -55,6 +55,7 @@ typedef struct {
 	const gchar	*lang;
 	GtkListStore	*liststore_nc;
 	GtkListStore	*liststore_metadata;
+	gboolean	 clearing_store;
 } GcmViewerPrivate;
 
 typedef enum {
@@ -329,7 +330,9 @@ gcm_viewer_update_get_profiles_cb (GObject *source_object,
 	}
 
 	/* clear existing list */
+	viewer->clearing_store = TRUE;
 	gtk_list_store_clear (viewer->list_store_profiles);
+	viewer->clearing_store = FALSE;
 
 	/* update each list */
 	for (i=0; i<profile_array->len; i++) {
@@ -1277,6 +1280,10 @@ gcm_viewer_profiles_treeview_clicked_cb (GtkTreeSelection *selection,
 	GtkTreeIter iter;
 	CdProfile *profile;
 
+	/* ignore */
+	if (viewer->clearing_store)
+		return;
+
 	/* This will only work in single or browse selection mode! */
 	if (!gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		g_debug ("no row selected");
@@ -1313,7 +1320,7 @@ gcm_viewer_client_profile_removed_cb (CdClient *client,
 				      GcmViewerPrivate *viewer)
 {
 	g_debug ("%s removed, rescanning",
-		 cd_profile_get_id (profile));
+		 cd_profile_get_object_path (profile));
 	gcm_viewer_update_profile_list (viewer);
 }
 
@@ -1786,7 +1793,7 @@ main (int argc, char **argv)
 	gchar *filename = NULL;
 	GcmViewerPrivate *viewer;
 	GOptionContext *context;
-	guint xid;
+	guint xid = 0;
 	int status = 0;
 	gboolean ret;
 	GError *error = NULL;
